# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .measurement_unit_code import MeasurementUnitCode
from .service_id_qualifier import ServiceIdQualifier


class DrugIdentification(pydantic.BaseModel):
    service_id_qualifier: ServiceIdQualifier
    national_drug_code: str
    national_drug_unit_count: str
    measurement_unit_code: MeasurementUnitCode
    link_sequence_number: typing.Optional[str] = None
    pharmacy_prescription_number: typing.Optional[str] = None
    conversion_formula: typing.Optional[str] = None
    drug_description: typing.Optional[str] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
