# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CoverageLevel(str, enum.Enum):
    INDIVIDUAL = "INDIVIDUAL"
    FAMILY = "FAMILY"
    EMPLOYEE_ONLY = "EMPLOYEE_ONLY"

    def visit(
        self,
        individual: typing.Callable[[], T_Result],
        family: typing.Callable[[], T_Result],
        employee_only: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is CoverageLevel.INDIVIDUAL:
            return individual()
        if self is CoverageLevel.FAMILY:
            return family()
        if self is CoverageLevel.EMPLOYEE_ONLY:
            return employee_only()
