# This file was auto-generated by Fern from our API Definition.

from ........core.api_error import ApiError
from ..types.invalid_mrn_error_body import InvalidMrnErrorBody


class InvalidMrnError(ApiError):
    def __init__(self, body: InvalidMrnErrorBody):
        super().__init__(status_code=400, body=body)
