# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AuthorizationUnit(str, enum.Enum):
    VISIT = "VISIT"

    def visit(self, visit: typing.Callable[[], T_Result]) -> T_Result:
        if self is AuthorizationUnit.VISIT:
            return visit()
